@@ -99,18 +99,21 @@ def fill_options(scope):
         klass = globals()['_' + scope + 's']
         setattr(klass, fname, f)
 
+def add_operation(fname, v):
+    code, desc, paramType, paramDesc = v
+    f = operation_wrap(code)
+    f.__name__ = fname
+    f.__doc__ = desc + '\n\nArguments are the key to which the operation is applied and the ' + paramDesc
+    setattr(globals()['Database'], fname, f)
+    setattr(globals()['Transaction'], fname, f)
+
 def fill_operations():
     _dict = getattr(_opts, 'MutationType')
 
     for k,v in _dict.items():
         fname = k.lower()
-        code, desc, paramType, paramDesc = v
-        f = operation_wrap(code)
-        f.__name__ = fname
-        f.__doc__ = desc + '\n\nArguments are the key to which the operation is applied and the ' + paramDesc
-        setattr(globals()['Database'], fname, f)
-        setattr(globals()['Transaction'], fname, f)
-
+        add_operation(fname, v)
+        add_operation("bit_" + fname, v)
 
 for scope in ['ClusterOption', 'DatabaseOption', 'TransactionOption', 'NetworkOption']:
     fill_options(scope)
@@ -171,7 +174,7 @@ def transactional(*tr_args, **tr_kwargs):
 
         @functools.wraps(func)
         def wrapper(*args, **kwargs):
-            if isinstance(args[index], Transaction):
+            if isinstance(args[index], TransactionRead):
                 return func(*args, **kwargs)
 
             largs = list(args)
@@ -364,6 +367,7 @@ class TransactionRead(_FDBBase):
         return FDBRange(self, begin, end, limit, reverse, streaming_mode)
 
     def get_range_startswith(self, prefix, *args, **kwargs):
+        prefix = keyToBytes(prefix)
         return self.get_range(prefix, strinc(prefix), *args, **kwargs)
 
     def __getitem__(self, key):
@@ -887,7 +891,7 @@ class Cluster(FormerFuture):
         self.capi.fdb_cluster_set_option(self.cpointer, option, param, length)
 
 
-def create_cluster(cluster_file):
+def create_cluster(cluster_file=None):
     f = Future(_FDBBase.capi.fdb_create_cluster(optionalParamToBytes(cluster_file)[0]))
     cpointer = ctypes.c_void_p()
     f.block_until_ready()
@@ -1232,25 +1236,41 @@ def init(event_model=None):
 
             if event_model is not None:
                 if event_model == 'gevent':
-                    if platform.system() == 'Windows':
-                        raise Exception("The 'gevent' event_model is not supported on Windows.")
-
                     import gevent
-                    import gevent.socket
 
-                    class ThreadEvent(object):
-                        def __init__(self):
-                            self.pair = os.pipe()
+                    if gevent.__version__[0] != '0':
+                        def nullf(): pass
 
-                        def set(self):
-                            os.write(self.pair[1], '!')
+                        class ThreadEvent(object):
+                            def __init__(self):
+                                self.async = gevent.get_hub().loop.async()
+                                self.async.start(nullf)
 
-                        def wait(self):
-                            gevent.socket.wait_read(self.pair[0])
+                            def set(self):
+                                self.async.send()
 
-                        def __del__(self):
-                            os.close(self.pair[0])
-                            os.close(self.pair[1])
+                            def wait(self):
+                                gevent.get_hub().wait(self.async)
+                    else:
+                        # gevent 0.x doesn't have async, so use a pipe.  This doesn't work on Windows.
+                        if platform.system() == 'Windows':
+                            raise Exception("The 'gevent' event_model requires gevent 1.0 on Windows.")
+
+                        import gevent.socket
+
+                        class ThreadEvent(object):
+                            def __init__(self):
+                                self.pair = os.pipe()
+
+                            def set(self):
+                                os.write(self.pair[1], '!')
+
+                            def wait(self):
+                                gevent.socket.wait_read(self.pair[0])
+
+                            def __del__(self):
+                                os.close(self.pair[0])
+                                os.close(self.pair[1])
 
                     Future.Event = ThreadEvent
 
@@ -1334,8 +1354,8 @@ def _stop_on_exit():
         _network_thread.join()
 
 def strinc(key):
-    lastc = (ord(key[-1:]) + 1) % 256
-    if lastc:
-        return key[:-1] + chr(lastc)
-    else:
-        return strinc(key[:-1]) + chr(lastc)
+    key = key.rstrip(b'\xff')
+    if len(key) == 0:
+        raise ValueError('Key must contain at least one byte not equal to 0xFF.')
+
+    return key[:-1] + chr(ord(key[-1]) + 1)
