@@ -52,6 +52,9 @@ def _get_boundary_keys(db_or_tr, begin, end):
                 tr.on_error(e).wait()
 
 def get_boundary_keys(db_or_tr, begin, end):
+    begin = _impl.keyToBytes(begin)
+    end = _impl.keyToBytes(end)
+
     gen = _get_boundary_keys(db_or_tr, begin, end)
     try:
         next(gen)
